import logging

from .factory.OFXReaderFactory import OFXReaderFactory
from .factory.PDFReaderFactory import PDFReaderFactory
from .factory.XLSReaderFactory import XLSReaderFactory
from .model import BankStatement, BankStatementAdder

logger = logging.getLogger(__name__)


class OFXReaderBR:

    @staticmethod
    def run(files):
        if not files:
            logger.info('No files specified.')
            return

        xls_files = []
        ofx_files = []
        pdf_files = []

        for file in files:
            try:
                if '.xls' in file.filename:
                    xls_files.append(file)
                elif '.pdf' in file.filename:
                    pdf_files.append(file)
                else:
                    ofx_files.append(file)
            except AttributeError:
                if '.xls' in file.name:
                    xls_files.append(file)
                elif '.pdf' in file.name:
                    pdf_files.append(file)
                else:
                    ofx_files.append(file)

        logger.info(ofx_files)
        logger.info(xls_files)
        logger.info(pdf_files)

        file_status = {}

        # chamar o leitor ofx
        factory_ofx = OFXReaderFactory()
        reader_controller = factory_ofx.createReaderController()
        ofx_bank_stmts = reader_controller.read(factory_ofx, files=ofx_files)
        ofx_status = reader_controller.status
        file_status.update(ofx_status)

        # chamar o leitor xls
        factory_xls = XLSReaderFactory()
        reader_controller = factory_xls.createReaderController()
        xls_bank_stmts = reader_controller.read(factory_xls, files=xls_files)
        xls_status = reader_controller.status
        file_status.update(xls_status)

        # chamar o leitor pdf
        factory_pdf = PDFReaderFactory()
        reader_controller = factory_pdf.createReaderController()
        pdf_bank_stmts = reader_controller.read(factory_pdf, files=pdf_files)
        pdf_status = reader_controller.status
        file_status.update(pdf_status)

        bank_stmt = BankStatement()
        adder = BankStatementAdder()

        for bs in ofx_bank_stmts:
            bank_stmt = adder.add(bank_stmt, bs, True)
        for bs in xls_bank_stmts:
            bank_stmt = adder.add(bank_stmt, bs, True)
        for bs in pdf_bank_stmts:
            bank_stmt = adder.add(bank_stmt, bs, True)

        logger.info(bank_stmt)

        return bank_stmt, file_status
